==> react-native-drag-text-editor-1.0.0.tgz: package/src/components/rotationSnapPoint/RotationSnapPoint.tsx <==
import React, {memo, useMemo} from 'react';
import Animated, {
  runOnJS,
  useAnimatedGestureHandler,
  useAnimatedStyle,
} from 'react-native-reanimated';
import {PanGestureHandler} from 'react-native-gesture-handler';
import {rotation, getCenters} from '../../utils/calculate';
import styles from './styles';
import {useRNDTInternal} from '../../hooks';
import {ROTATION_SNAP_POINTS, OFFSET} from '../../constants';
import {Keyboard, StyleProp, ViewStyle} from 'react-native';
import {rotationComponentPropTypes} from './types';

const RotationSnapPoint = ({
  side,
  customRotationComponent,
}: rotationComponentPropTypes) => {
  const internals = useRNDTInternal();

  const snapPointOffset = useMemo(() => {
    if (side == ROTATION_SNAP_POINTS.BOTTOM) {
      return OFFSET.BOTTOM_CENTER;
    } else if (side == ROTATION_SNAP_POINTS.TOP) {
      return OFFSET.TOP_CENTER;
    } else if (side == ROTATION_SNAP_POINTS.LEFT) {
      return OFFSET.LEFT_CORNER;
    } else {
      return OFFSET.LEFT_CORNER;
    }
  }, [side]);

  const rotateHandler = useAnimatedGestureHandler({
    onStart: (_ev: any, ctx: any) => {
      runOnJS(Keyboard.dismiss)();
      ctx.centers = getCenters(internals);
    },
    onActive: (_ev, ctx) => {
      internals.rotationAngle.value = rotation(_ev, ctx, snapPointOffset);
    },
  });

  const borderStatusStyle = useAnimatedStyle(() => ({
    display: internals.borderStatus.value ? 'flex' : 'none',
  }));

  const rotationStylesSelector: {
    [key in ROTATION_SNAP_POINTS]: StyleProp<ViewStyle>;
  } = {
    left: styles.left,
    bottom: styles.bottom,
    top: styles.top,
  };
  const rotationStyle = rotationStylesSelector[side as ROTATION_SNAP_POINTS];

  return (
    <PanGestureHandler onGestureEvent={rotateHandler}>
      <Animated.View style={[rotationStyle, borderStatusStyle]}>
        {customRotationComponent()}
      </Animated.View>
    </PanGestureHandler>
  );
};

export default memo(RotationSnapPoint);

==> react-native-drag-text-editor-1.0.1.tgz: package/src/components/rotationSnapPoint/RotationSnapPoint.tsx <==
import React, { memo, useMemo } from 'react';
import Animated, {
  runOnJS,
  useAnimatedGestureHandler,
  useAnimatedStyle,
} from 'react-native-reanimated';
import { PanGestureHandler } from 'react-native-gesture-handler';
import { rotation, getCenters } from '../../utils/calculate';
import styles from './styles';
import { useRNDTInternal } from '../../hooks';
import { ROTATION_SNAP_POINTS, OFFSET } from '../../constants';
import { Keyboard, StyleProp, ViewStyle } from 'react-native';
import { rotationComponentPropTypes } from './types';

const RotationSnapPoint = ({
  side,
  customRotationComponent,
}: rotationComponentPropTypes) => {
  const internals = useRNDTInternal();

  const snapPointOffset = useMemo(() => {
    if (side === ROTATION_SNAP_POINTS.BOTTOM) {
      return OFFSET.BOTTOM_CENTER;
    } else if (side === ROTATION_SNAP_POINTS.TOP) {
      return OFFSET.TOP_CENTER;
    } else if (side === ROTATION_SNAP_POINTS.LEFT) {
      return OFFSET.LEFT_CORNER;
    } else {
      return OFFSET.LEFT_CORNER;
    }
  }, [side]);

  const rotateHandler = useAnimatedGestureHandler({
    onStart: (_ev: any, ctx: any) => {
      runOnJS(Keyboard.dismiss)();
      ctx.centers = getCenters(internals);
    },
    onActive: (_ev, ctx) => {
      internals.rotationAngle.value = rotation(_ev, ctx, snapPointOffset);
    },
  });

  const borderStatusStyle = useAnimatedStyle(() => ({
    display: internals.borderStatus.value ? 'flex' : 'none',
  }));

  const rotationStylesSelector: {
    [key in ROTATION_SNAP_POINTS]: StyleProp<ViewStyle>;
  } = {
    left: styles.left,
    bottom: styles.bottom,
    top: styles.top,
  };
  const rotationStyle = rotationStylesSelector[side as ROTATION_SNAP_POINTS];

  return (
    <PanGestureHandler onGestureEvent={rotateHandler}>
      <Animated.View style={[rotationStyle, borderStatusStyle]}>
        {customRotationComponent()}
      </Animated.View>
    </PanGestureHandler>
  );
};

export default memo(RotationSnapPoint);
